pub struct OneShotJob {
pub duration: i32,
pub job: String,
}Expand description
A one shot job to run a task at a scheduled interval in the background.
Fields
duration: i32The duration in seconds to wait until calling this job.
job: StringA function name to call for each scheduled cron execution.