#[repr(i32)]pub enum InstructionKind {
Plugin = 0,
GetMetadata = 1,
Install = 2,
Initialize = 3,
Shutdown = 4,
ChatMessage = 5,
ChatCommand = 6,
ScheduledJob = 7,
}Expand description
[Internal] Kinds of instructions that can be sent to hank plugins.
Variants
Plugin = 0
Plugin entry point.
GetMetadata = 1
Get the plugins metadata.
Install = 2
Call the plugins install function. (only happens once)
Initialize = 3
Call the plugins initialize function. (happens on every load)
Shutdown = 4
Call the plugins shutdown function. (happens on reload, unload, uninstall)
ChatMessage = 5
Call the plguins chat message handler.
ChatCommand = 6
Call the plguins chat command handler.
ScheduledJob = 7
Call the plguins scheduled job handler.
Implementations
sourceimpl InstructionKind
impl InstructionKind
sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.