pub struct Argument {
pub name: String,
pub description: String,
pub default_value: Option<String>,
pub required: bool,
pub short: Option<String>,
pub long: Option<String>,
}Expand description
Arguments for a plugin or a plugins subcommands.
Fields
name: StringArgument name.
description: StringArgument description.
default_value: Option<String>Optional argument default value.
required: boolWhether or not this argument is required.
short: Option<String>Sets the short version of the argument without the preceding -.
long: Option<String>Sets the long version of the argument without the preceding –.
Implementations