pub struct Instruction {
pub kind: i32,
pub input: Vec<u8>,
pub target: Option<String>,
}Expand description
[Internal] An instruction to send to hank plugin.
Fields
kind: i32The kind of instruction to send to the hank plugin.
input: Vec<u8>An input to send to the hank plugin.
target: Option<String>An optional target plugin name to send the instruciton to.
Implementations
sourceimpl Instruction
impl Instruction
sourcepub fn kind(&self) -> InstructionKind
pub fn kind(&self) -> InstructionKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
sourcepub fn set_kind(&mut self, value: InstructionKind)
pub fn set_kind(&mut self, value: InstructionKind)
Sets kind to the provided enum value.