hank_types::hank::plugin

Struct Metadata

source
pub struct Metadata {
Show 16 fields pub name: String, pub description: String, pub version: String, pub database: bool, pub access_checks: Option<AccessCheckChain>, pub escalation_key: Option<String>, pub escalated_privileges: Vec<i32>, pub author: String, pub handles_commands: bool, pub handles_messages: bool, pub command_name: Option<String>, pub aliases: Vec<String>, pub arguments: Vec<Argument>, pub subcommands: Vec<Command>, pub allowed_hosts: Vec<String>, pub pool_size: Option<i32>,
}
Metadata for a plugin.

Fields

name: String

The plguins name.

description: String

A short description of the plugin.

version: String

A version string for the plugin. Should follow semver.

@see: https://semver.org/

database: bool

When true, a SQLite3 database will be created for the plugin. @deprecated All plugins get a database by default now.

access_checks: Option<AccessCheckChain>

Access checks

All functionality of this plugin can optionally be gated by accses checks.

escalation_key: Option<String>

A secret escalation key that grants this plugin specific escalated privileges.

escalated_privileges: Vec<i32>

A list of escalated privileges that this plugin requests to use.

author: String

The author of the plugin.

handles_commands: bool

Whether or not this plugin handles commands.

handles_messages: bool

Whether or not this plugin handles messages.

command_name: Option<String>

Optionally override the plugin command name.

aliases: Vec<String>

Optional aliases for the plugin command.

arguments: Vec<Argument>

Arguments for the plugin command.

subcommands: Vec<Command>

Plugin subcommands.

allowed_hosts: Vec<String>

Hosts that this plugin requests permissions to access via HTTP.

pool_size: Option<i32>

Pool size this plugin requests.

Implementations

source

impl Metadata

source

pub fn escalation_key(&self) -> &str

Returns the value of escalation_key, or the default value if escalation_key is unset.

source

pub fn escalated_privileges( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(_: i32) -> Option<EscalatedPrivilege>>

Returns an iterator which yields the valid enum values contained in escalated_privileges.

source

pub fn push_escalated_privileges(&mut self, value: EscalatedPrivilege)

Appends the provided enum value to escalated_privileges.

source

pub fn command_name(&self) -> &str

Returns the value of command_name, or the default value if command_name is unset.

source

pub fn pool_size(&self) -> i32

Returns the value of pool_size, or the default value if pool_size is unset.