pub struct UnloadPluginInput {
pub plugin: String,
pub cleanup: bool,
}Expand description
[Internal] Input to an unload plugin request to Hank.
Fields
plugin: StringThe plugin to unload.
cleanup: boolWhether or not hank should clean up any plugin assets, e.g. database file. This should be set to true if this plugin is being unloaded as a result of an uninstall command.